@@ -4,18 +4,20 @@ from Corellia.kvstore import KVStore
 from ..config import config
 from uuid import uuid1
 import Husky
-
-client = Client(config.host, "Briareus", pickler=Husky, serialize=True, interval=0.1)
-
+from gevent import sleep
 
 class Cloud(object):
     def __init__(self, f):
         self.f = f
+        self.put_client = Client(config.host, "Briareus", pickler=Husky, serialize=True, interval=0.1)
+        self.get_client = Client(config.host, "Briareus", pickler=Husky, serialize=False)
+        # self.client = Client(config.host, "Briareus", pickler=Husky, serialize=True, interval=0.01)
 
     def __call__(self, *args):
-        res = Client(config.host, "Briareus", pickler=Husky, serialize=True, interval=0.1).eval(self.f, args)
-        print "res:", res
-        # return Husky.loads(res)
+        key = self.put_client.put_task("eval", (self.f, args))
+        return self.get_client.get_result(key, block=True)
+        # return Client(config.host, "Briareus", pickler=Husky, serialize=False).eval(self.f, args)
+        # return self.client.eval(self.f, args)
 
     def __getstate__(self):
         return Husky.dumps(self.f)
@@ -47,10 +49,14 @@ class CachedData(object):
     def put(self, value):
         self.id = uuid1().hex
         value = Husky.dumps(value)
-        KVStore(config.host, self.name).set(self.id, value, serialize=False)
+        KVStore(config.host, self.name).set(self.id, value, serialize=True)
 
     def get(self, key):
-        res = KVStore(config.host, self.name).get(key)
+        store = KVStore(config.host, self.name)
+        res = store.get(key, serialize=False)
+        while not res:
+            sleep(0.01)
+            res = store.get(key, serialize=False)
         return Husky.loads(res)
 
     def __del__(self):
