@@ -1,3 +1,4 @@
+from gevent import monkey; monkey.patch_all()
 from utils import CachedData
 
 class Runtime(object):
@@ -16,12 +17,10 @@ class Runtime(object):
 
     def eval(self, f, args):
         f = self.getvalue(f)
-        print f
         return f(*map(self.getvalue, args))
 
 def run():
-    from gevent import monkey; monkey.patch_all()
     from Corellia.worker import WorkerPool
     import Husky
     from ..config import config
-    WorkerPool(config.host, "Briareus", pickler=Husky, serialize=True, interval=0.1, mass=False, num=5).run(Runtime)
\ No newline at end of file
+    WorkerPool(config.host, "Briareus", pickler=Husky, serialize=False, num=1).run(Runtime)
\ No newline at end of file
